Method: Arel::SelectManager#order_without_sqlserver
- Defined in:
- lib/arel/visitors/sqlserver.rb
#order_without_sqlserver ⇒ Object
Getting real Ordering objects is very important for us. We need to be able to call #uniq on a colleciton of them reliably as well as using their true object attributes to mutate them to grouping objects for the inner sql during a select statment with an offset/rownumber. So this is here till ActiveRecord & ARel does this for us instead of using SqlLiteral objects.
31 |
# File 'lib/arel/visitors/sqlserver.rb', line 31 alias :order_without_sqlserver :order |